.. _isomorphism:

***********
Isomorphism
***********

.. toctree::
   :maxdepth: 2

.. automodule:: networkx.algorithms.isomorphism
.. autosummary::
   :toctree: generated/

   is_isomorphic
   could_be_isomorphic
   fast_could_be_isomorphic
   faster_could_be_isomorphic

Advanced Interfaces
-------------------
.. toctree::
   :maxdepth: 2

   isomorphism.vf2
   isomorphism.ismags

